@@ -1,29 +1,15 @@
 /*
- *   Copyright 2008 by Aaron Seigo <aseigo@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2008 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include <kpackage/version.h>
 
-#include <QDebug>
+#include "kpackage_debug.h"
 
 namespace KPackage
 {
-
 unsigned int version()
 {
     return PACKAGE_VERSION;
@@ -53,7 +39,7 @@ bool isPluginVersionCompatible(unsigned int version)
 {
     if (version == quint32(-1)) {
         // unversioned, just let it through
-        qWarning() << "unversioned plugin detected, may result in instability";
+        qCWarning(KPACKAGE_LOG) << "unversioned plugin detected, may result in instability";
         return true;
     }
 
@@ -63,7 +49,7 @@ bool isPluginVersionCompatible(unsigned int version)
 
     if (version < minVersion || version > maxVersion) {
 #ifndef NDEBUG
-        // qDebug() << "plugin is compiled against incompatible KPackage version  " << version
+        // qCDebug(KPACKAGE_LOG) << "plugin is compiled against incompatible KPackage version  " << version
         //         << "This build is compatible with" << PACKAGE_VERSION_MAJOR << ".0.0 (" << minVersion
         //         << ") to" << PACKAGE_VERSION_STRING << "(" << maxVersion << ")";
 #endif
@@ -74,4 +60,3 @@ bool isPluginVersionCompatible(unsigned int version)
 }
 
 } // namespace
-
